<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

| Language              | Code | All Modules | Lemmatiser | Transcriber | Translator |
| --------------------- | ---- | ----------- | ---------- | ----------- | ---------- |
| Albanian              | sq   |             |            |             | ✅         |
| Arabic                | ar   |             |            | ✅          | ✅         |
| Azerbaijani           | az   |             |            |             | ✅         |
| Basque                | eu   |             |            |             | ✅         |
| Bengali               | bn   |             |            |             | ✅         |
| Bulgarian             | bg   |             |            |             | ✅         |
| Catalan               | ca   | ✅          | ✅         | ✅          | ✅         |
| Chinese               | zh   | ✅          | ✅         | ✅          | ✅         |
| Chinese (traditional) | zt   |             |            |             | ✅         |
| Croatian              | hr   |             | ✅         | ✅          |            |
| Czech                 | cs   |             |            | ✅          | ✅         |
| Danish                | da   | ✅          | ✅         | ✅          | ✅         |
| Dutch                 | nl   | ✅          | ✅         | ✅          | ✅         |
| English               | en   | ✅          | ✅         | ✅          | ✅         |
| Esperanto             | eo   |             |            |             | ✅         |
| Estonian              | et   |             |            |             | ✅         |
| Finnish               | fi   | ✅          | ✅         | ✅          | ✅         |
| French                | fr   | ✅          | ✅         | ✅          | ✅         |
| Galician              | gl   |             |            |             | ✅         |
| German                | de   | ✅          | ✅         | ✅          | ✅         |
| Greek                 | el   | ✅          | ✅         | ✅          | ✅         |
| Hebrew                | he   |             |            | ✅          | ✅         |
| Hindi                 | hi   |             |            | ✅          | ✅         |
| Hungarian             | hu   |             |            | ✅          | ✅         |
| Indonesian            | id   |             |            |             | ✅         |
| Irish                 | ga   |             |            |             | ✅         |
| Italian               | it   | ✅          | ✅         | ✅          | ✅         |
| Japanese              | ja   | ✅          | ✅         | ✅          | ✅         |
| Korean                | ko   | ✅          | ✅         | ✅          | ✅         |
| Latvian               | lv   |             |            |             | ✅         |
| Lithuanian            | lt   |             | ✅         |             | ✅         |
| Macedonian            | mk   |             | ✅         |             |            |
| Malay                 | ms   |             |            |             | ✅         |
| Malayalam             | ml   |             |            | ✅          |            |
| Norwegian             | no   |             |            | ✅          |            |
| Norwegian Bokmål      | nb   |             | ✅         |             | ✅         |
| Norwegian Nynorsk     | nn   |             |            | ✅          |            |
| Persian               | fa   |             |            | ✅          | ✅         |
| Polish                | pl   | ✅          | ✅         | ✅          | ✅         |
| Portuguese            | pt   | ✅          | ✅         | ✅          | ✅         |
| Romanian              | ro   |             | ✅         |             | ✅         |
| Russian               | ru   | ✅          | ✅         | ✅          | ✅         |
| Slovak                | sk   |             |            | ✅          | ✅         |
| Slovenian             | sl   | ✅          | ✅         | ✅          | ✅         |
| Spanish               | es   | ✅          | ✅         | ✅          | ✅         |
| Swedish               | sv   |             | ✅         |             | ✅         |
| Tagalog               | tl   |             |            |             | ✅         |
| Telugu                | te   |             |            | ✅          |            |
| Thai                  | th   |             |            |             | ✅         |
| Turkish               | tr   |             |            | ✅          | ✅         |
| Ukrainian             | uk   | ✅          | ✅         | ✅          | ✅         |
| Urdu                  | ur   |             |            | ✅          | ✅         |
| Vietnamese            | vi   |             |            | ✅          |            |
